@@ -23,4 +23,4 @@ from dnnlab import image_detection
 from dnnlab import input_pipeline
 from dnnlab import metric_learning
 from dnnlab import image_to_image
-from dnnlab import image_classification
+from dnnlab import interpretability
