@@ -235,7 +235,7 @@ class YOLO():
     def compile(self,
                 optimizer="adam",
                 lr=1e-4,
-                loss="vanilla",
+                loss="ciou",
                 loss_scaling=False):
         """Defines the optimization part of the learning algorithm to our
         learning model.
@@ -604,7 +604,7 @@ class YOLO():
         grid_coord = yolo_grid(1, grid_h, grid_w, n_boxes)
         if label:
             p_box_xy, p_box_wh, p_box_conf, p_box_class = extract_label(
-                predictions, tb=True)
+                predictions)
         else:
             p_box_xy, p_box_wh, p_box_conf, p_box_class = extract_model_output(
                 predictions, grid_coord, anchors)
