@@ -22,9 +22,6 @@ import tensorflow as tf
 def create_dataset(tfrecords,
                    buffer_size,
                    num_parallel_reads,
-                   height,
-                   width,
-                   depth,
                    seed,
                    batch_size,
                    prefetching=True,
@@ -49,7 +46,7 @@ def create_dataset(tfrecords,
 
     # pre-processing function but apply it in parallel on multiple samples.
     parsed_dataset = raw_dataset.map(
-        lambda example: _parse_tfrecords(example, height, width, depth, key),
+        lambda example: _parse_tfrecords(example, key),
         num_parallel_calls=tf.data.experimental.AUTOTUNE)
 
     parsed_dataset = parsed_dataset.shuffle(buffer_size, seed=seed)
@@ -64,7 +61,7 @@ def create_dataset(tfrecords,
     return parsed_dataset
 
 
-def _parse_tfrecords(example, height, width, depth, key):
+def _parse_tfrecords(example, key):
     # Create a dictionary describing the features.
     feature_description = {
         'height': tf.io.FixedLenFeature([], tf.int64, default_value=[-1]),
@@ -78,11 +75,7 @@ def _parse_tfrecords(example, height, width, depth, key):
     #example = tf.io.parse_example(example, feature_description)
     img = example[key]
     # Convert encoded jpeg bytes into tensors.
-    img = tf.image.decode_jpeg(img, channels=depth)
+    img = tf.io.decode_jpeg(img)
     img = tf.cast(img, tf.float32)
-    # Normalize img.
-    img = img / 255.
-
-    img = tf.image.resize(img, (height, width))
 
     return img
