@@ -21,9 +21,6 @@ import tensorflow as tf
 def create_dataset(tfrecords,
                    buffer_size,
                    num_parallel_reads,
-                   height,
-                   width,
-                   depth,
                    seed,
                    batch_size,
                    keys,
@@ -51,13 +48,12 @@ def create_dataset(tfrecords,
     # pre-processing function but apply it in parallel on multiple samples.
     if encoding:
         parsed_dataset = raw_dataset.map(
-            lambda example: _parse_tfrecords_encoded(
-                example, height, width, depth, keys, one_hot_labels),
+            lambda example: _parse_tfrecords_encoded(example, keys,
+                                                     one_hot_labels),
             num_parallel_calls=tf.data.experimental.AUTOTUNE)
     else:
         parsed_dataset = raw_dataset.map(
-            lambda example: _parse_tfrecords_raw(example, height, width, depth,
-                                                 keys),
+            lambda example: _parse_tfrecords_raw(example, keys),
             num_parallel_calls=tf.data.experimental.AUTOTUNE)
 
     parsed_dataset = parsed_dataset.shuffle(buffer_size, seed=seed)
@@ -72,8 +68,7 @@ def create_dataset(tfrecords,
     return parsed_dataset
 
 
-def _parse_tfrecords_encoded(example, height, width, depth, keys,
-                             one_hot_labels):
+def _parse_tfrecords_encoded(example, keys, one_hot_labels):
     # Create a dictionary describing the features.
     feature_description = {
         keys[0]: tf.io.FixedLenFeature([], tf.string, default_value=""),
@@ -84,12 +79,8 @@ def _parse_tfrecords_encoded(example, height, width, depth, keys,
     example = tf.io.parse_single_example(example, feature_description)
     img_source = example[keys[0]]
     # Convert encoded jpeg bytes into tensors. TODO decode_image
-    img_source = tf.image.decode_jpeg(img_source, channels=depth)
+    img_source = tf.io.decode_jpeg(img_source)
     img_source = tf.cast(img_source, tf.float32)
-    # Normalize img.
-    if tf.math.reduce_max(img_source) > 1.0:
-        img_source = img_source / 255.
-    img_source = tf.image.resize(img_source, (height, width))
 
     if not one_hot_labels:
         label = tf.argmax(example[keys[1]], axis=0)
@@ -99,7 +90,7 @@ def _parse_tfrecords_encoded(example, height, width, depth, keys,
     return img_source, label
 
 
-def _parse_tfrecords_raw(example, height, width, depth, keys):
+def _parse_tfrecords_raw(example, keys):
     # Create a dictionary describing the features.
     feature_description = {
         keys[0]: tf.io.FixedLenFeature([], tf.string, default_value=""),
@@ -126,8 +117,6 @@ def _parse_tfrecords_raw(example, height, width, depth, keys):
     # Restore spatial resolution of images.
     height_orig = tf.cast(example['height'], tf.int32)
     width_orig = tf.cast(example['width'], tf.int32)
-    # Defaults to grayscale if feature is missing in example. Doesnt work TODO
-    # depth = tf.cast(example['depth'], tf.int32)
     depth_orig = 1
 
     image_shape = tf.stack([height_orig, width_orig, depth_orig])
@@ -139,15 +128,4 @@ def _parse_tfrecords_raw(example, height, width, depth, keys):
     img_source = tf.cast(img_source, tf.float32)
     img_target = tf.cast(img_target, tf.float32)
 
-    # Normalize images.
-    if tf.math.reduce_max(img_source) > 1.0:
-        img_source = img_source / 255.
-
-    if tf.math.reduce_max(img_target) > 1.0:
-        img_target = img_target / 255.
-
-    # Rescale images.
-    img_source = tf.image.resize(img_source, (height, width))
-    img_target = tf.image.resize(img_target, (height, width))
-
     return img_source, img_target
