@@ -358,7 +358,7 @@ def _loss_class(
         [type]: [description]
     """
     # Indicator function to only weigh class predictions if an object exists.
-    class_mask = tf.squeeze(true_box_conf) * lambda_class
+    class_mask = true_box_conf * lambda_class
     # Use xentropy between class probabilities.
     #loss_class = tf.nn.sparse_softmax_cross_entropy_with_logits(
     #    labels=true_box_class, logits=p_box_class)
